# Teager C / C++ AST Traversal

[![Build Status](https://travis-ci.org/jemtucker/teager.svg?branch=master)](https://travis-ci.org/jemtucker/teager)

A libclang powered C / C++ AST traversal library for python.

## Build

```
./setup.py install && ./setup.py test
```
